#!/usr/bin/python
# -*- python -*-

#
# box_info.py -- class to manage realtime info [as time, volume, ID3tags]
#
# Copyright (c) 2004 DEGOIS Damien <damien@degois.info> 
# Licensed under the GNU GPL. For full terms see the file COPYING.
#
# Cf LICENSE provided with those files
#

import threading, curses
from time import sleep
import txt_tools

class Info(threading.Thread):
    def __init__(self, screen, mp3, mixer,version, name=None):
        threading.Thread.__init__(self, target=self.run, name=name, args=() )
        self.screen = screen
        (self.maxy,self.maxx) = screen.getmaxyx()
        self.playa = mp3
        self.mixa = mixer
        self.start()
        self.orders = []
        self.version = version

    def run(self):
        while 1:
            if self.OrdersHandler() == "exit":
                break

    def OrdersHandler(self,sleeper=1):
        order = ""
        try:
            order = self.orders.pop()
        except:
            1
        if sleeper:
            sleep(0.1)

        for x in range (1,6):
            self.screen.addstr(x,1," "*(self.maxx-2))

        self.screen.addstr(1,1, "Random: ",curses.A_BOLD)
        if self.playa.random:
            rand = "On"
        else:
            rand = "Off"

        self.screen.addstr(1,9, rand,0)
        self.screen.addstr(1,13, "Playlist: ",curses.A_BOLD)
        self.screen.addstr(1,23, str(self.playa.stack.size())+" files remaining",0)
        self.screen.addstr(1,self.maxx-13,"PyMP3" , curses.A_BOLD)
        self.screen.addstr(1,self.maxx-7, "v"+str(self.version),0)
        
        if self.playa.mf:
            line = 4
            if self.playa.mf.current_time():
                tot = float(self.playa.mf.total_time())
                cur = float(self.playa.mf.current_time())
                min_tot = int(tot/60000)
                sec_tot = int((tot-min_tot*60000)/1000)
                min_cur = int(cur/60000)
                sec_cur = int((cur-min_cur*60000)/1000)
                if sec_cur < 10:
                    sec_cur = "0"+str(sec_cur)
                if sec_tot < 10:
                    sec_tot = "0"+str(sec_tot)
                txt_time = "Time : "
                txt_time_var = "%d:%s / %d:%s "%(min_cur,sec_cur,min_tot,sec_tot)
                if tot:
                    ratio = cur/tot
                else:
                    ratio = 0
                self.screen.hline(line, 1, '-', self.maxx-2)
                lng_egal = ratio*(self.maxx-3-len(txt_time)-len(txt_time_var))
                self.screen.hline(line, len(txt_time)+len(txt_time_var)+1, "=", int(lng_egal),curses.A_BOLD)
                self.screen.addstr(line,1+7, txt_time_var,0 )

        middle = int((self.maxx-2)/2)
        self.screen.addstr(2,1, "Artist: ",curses.A_BOLD )
        self.screen.addstr(2,middle, "Album: ",curses.A_BOLD )
        self.screen.addstr(3,1, "N"+chr(176)+": ",curses.A_BOLD )
        self.screen.addstr(3,11, "Title: ",curses.A_BOLD )
        
        if self.playa.id3 != None:
            track_num = 0
            track_on = 0
            try:
                (track_num, track_on) = self.playa.id3.tracknum
            except:
                try:
                    (track_num,) = self.playa.id3.tracknum
                except:
                    track_num = "--"
            if track_on:
                txt_track_num = str(track_num)+"/"+str(track_on)
            else:
                if track_num:
                    txt_track_num = str(track_num)
                else:
                    txt_track_num = "--"

            try:
                artist = self.playa.id3.artist.replace("\x00","")
            except:
                artist = "--"

            try:
                album = self.playa.id3.album.replace("\x00","")
            except:
                album = "--"

            try:
                title = self.playa.id3.title.replace("\x00","")
            except:
                title = "--"


            self.screen.addstr(2,9, txt_tools.limit(str(artist),middle-10),0 )
            self.screen.addstr(2,middle+7, txt_tools.limit(str(album),middle-7),0 )
            self.screen.addstr(3,1+4, str(txt_track_num),0 )
            self.screen.addstr(3,11+7, txt_tools.limit(str(title),self.maxx-19),0 )

            # self.screen.addstr(2,9, str("plop"),0 )
            # self.screen.addstr(2,middle+8, str("pouet"),0 )
            # self.screen.addstr(3,1+4, str("truc"),0 )
            # self.screen.addstr(3,11+7, str("zob"),0 )

            # print self.playa.id3.title
        self.screen.addstr(4,1, "Time : ",curses.A_BOLD )
                
        if self.mixa.get():
            line = 5
            (a,b) = self.mixa.get()
            a = float(a)
            b = float(b)
            self.screen.addstr(line,1,"Vol:",curses.A_BOLD)
            self.screen.hline(line,6,'-',self.maxx-8)
            self.screen.hline(line,6,'|',int(((a+b)/2)/100*(self.maxx-8)))
            #self.screen.addstr(4,1,str(((a+b)/2)/100*(self.maxx-8)),curses.A_BOLD)
        self.screen.refresh()
                
        if order == "exit":
            return "exit"

        
